@@ -72,17 +72,17 @@ public:
         m_expireDuration = duration;
     }
 
-    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const override;
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    virtual QModelIndex parent(const QModelIndex &child) const override;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    QModelIndex parent(const QModelIndex &child) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
     Job jobForIndex(const QModelIndex &index) const;
     QModelIndex indexForJob(const Job &job, int column);
 
-    void setHostId(unsigned int hostid);
-    unsigned int hostId() const { return m_hostid; }
+    void setHostId(unsigned int hostId);
+    unsigned int hostId() const { return m_hostId; }
     void setJobType(JobType type) { m_jobType = type; }
     JobType jobType() const { return m_jobType; }
 
@@ -122,7 +122,7 @@ private:
 
     struct FinishedJob
     {
-        FinishedJob(uint _time = 0, uint _jobId = 0)
+        explicit FinishedJob(uint _time = 0, uint _jobId = 0)
             : time(_time)
             , jobId(_jobId) {}
         uint time;
@@ -135,7 +135,7 @@ private:
 
     QTimer *m_expireTimer;
     JobType m_jobType;
-    unsigned int m_hostid;
+    unsigned int m_hostId;
 };
 
 class JobListSortFilterProxyModel
@@ -143,10 +143,10 @@ class JobListSortFilterProxyModel
 {
     Q_OBJECT
 public:
-    JobListSortFilterProxyModel(QObject *parent = nullptr);
+    explicit JobListSortFilterProxyModel(QObject *parent = nullptr);
 
 protected:
-    virtual bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 };
 
 #endif
