@@ -39,9 +39,9 @@ class DetailedHostView
     Q_OBJECT
 
 public:
-    DetailedHostView(QObject *parent);
+    explicit DetailedHostView(QObject *parent);
 
-    virtual void setMonitor(Monitor *monitor) override;
+    void setMonitor(Monitor *monitor) override;
 
     QWidget *widget() const override;
 
