@@ -75,19 +75,22 @@ void ProgressWidget::resizeEvent(QResizeEvent *) {
 
 FlowTableView::FlowTableView(QObject *parent)
     : StatusView(parent)
-    , m_updateTimer(new QTimer)
     , m_widget(new QTableWidget)
+    , m_updateTimer(new QTimer)
 {
     m_widget->setColumnCount(4);
     QStringList labels;
     labels << tr("Host") << tr("File") << tr("History") << tr("State");
     m_widget->setHorizontalHeaderLabels(labels);
     m_widget->horizontalHeader()->setSectionResizeMode(2, QHeaderView::Stretch);
+    m_widget->horizontalHeader()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
     m_widget->verticalHeader()->hide();
     m_widget->setSelectionMode(QAbstractItemView::NoSelection);
 
     m_updateTimer->setInterval(50);
     m_updateTimer->start();
+
+    createKnownHosts();
 }
 
 void FlowTableView::update(const Job &job)
@@ -126,19 +129,12 @@ void FlowTableView::update(const Job &job)
 
     // update the host column for the server requesting the job
     QTableWidgetItem *hostNameItem = m_widget->item(serverRow, 0);
-    int usageCount = hostNameItem->data(Qt::UserRole).toInt();
-    if (job.state == Job::LocalOnly || job.state == Job::Compiling) {
-        ++usageCount;
-    } else if (job.state == Job::Finished || job.state == Job::Failed) {
-        --usageCount;
-    }
-
-    hostNameItem->setData(Qt::UserRole, usageCount);
+    HostInfo *hostInfo = hostInfoManager()->find(serverId);
 
     QFont f = m_widget->font();
-    f.setBold(usageCount > 0);
+    f.setBold(hostInfo->numJobs() > 0);
     hostNameItem->setFont(f);
-    hostNameItem->setText(hostInfoText(hostInfoManager()->find(serverId), usageCount));
+    hostNameItem->setText(hostInfoText(hostInfo));
 }
 
 QWidget *FlowTableView::widget() const
@@ -146,14 +142,38 @@ QWidget *FlowTableView::widget() const
     return m_widget.data();
 }
 
-QString FlowTableView::hostInfoText(HostInfo *hostInfo, int runningProcesses) {
-    if (hostInfo->serverSpeed() == 0) { // host disabled
+QString FlowTableView::hostInfoText(HostInfo *hostInfo) {
+    if ((hostInfo->serverSpeed() == 0) && (hostInfo->numJobs() == 0)) { // host disabled
         return tr("%1 (Disabled)").arg(hostInfo->name());
     } else {
-        return tr("%1 (%2/%3)").arg(hostInfo->name()).arg(runningProcesses).arg(hostInfo->maxJobs());
+        return tr("%1 (%2/%3)").arg(hostInfo->name()).arg(hostInfo->numJobs()).arg(hostInfo->maxJobs());
     }
 }
 
+void FlowTableView::createKnownHosts()
+{
+    if (!hostInfoManager()) {
+        return;
+    }
+
+    m_widget->setRowCount(0);
+    m_idToRowMap.clear();
+
+    const HostInfoManager::HostMap hosts(hostInfoManager()->hostMap());
+
+    foreach(int hostid, hosts.keys()) {
+        checkNode(hostid);
+    }
+}
+
+void FlowTableView::setMonitor(Monitor *monitor)
+{
+    StatusView::setMonitor(monitor);
+
+    if (monitor)
+	    createKnownHosts();
+}
+
 void FlowTableView::checkNode(unsigned int hostId)
 {
     if (m_idToRowMap.contains(hostId)) {
@@ -165,8 +185,6 @@ void FlowTableView::checkNode(unsigned int hostId)
     widgetItem->setIcon(QIcon(QStringLiteral(":/images/icemonnode.png")));
     widgetItem->setToolTip(hostInfo->toolTip());
     widgetItem->setBackgroundColor(hostInfo->color());
-    // usage count
-    widgetItem->setData(Qt::UserRole, 0);
     widgetItem->setFlags(Qt::ItemIsEnabled);
     int insertRow = m_widget->rowCount();
     m_widget->setRowCount(insertRow + 1);
@@ -191,6 +209,7 @@ void FlowTableView::checkNode(unsigned int hostId)
 
 void FlowTableView::removeNode(unsigned int hostId)
 {
-    m_widget->removeRow(m_idToRowMap.value(hostId));
-    m_idToRowMap.remove(hostId);
+    Q_UNUSED(hostId);
+
+    createKnownHosts();
 }
