@@ -40,6 +40,7 @@
 #include <QResizeEvent>
 #include <QGraphicsScene>
 #include <QGraphicsView>
+#include <QDialogButtonBox>
 
 #include <math.h>
 
@@ -85,14 +86,14 @@ StarViewConfigDialog::StarViewConfigDialog(QWidget *parent)
     hline->setFrameShape(QFrame::HLine);
     hline->setFrameShadow(QFrame::Sunken);
     topLayout->addWidget(hline);
-    QPushButton *closeButton = new QPushButton(tr("&Close"));
-    closeButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
-    topLayout->addWidget(closeButton, 0, Qt::AlignRight);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    topLayout->addWidget(buttonBox);
 
     connect(mSuppressDomainName, SIGNAL(toggled(bool)),
             SLOT(slotSuppressDomainName(bool)));
 
-    connect(closeButton, SIGNAL(clicked()), SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), SLOT(accept()));
 }
 
 void StarViewConfigDialog::slotNodesPerRingChanged(int nodes)
@@ -478,23 +479,10 @@ void StarView::removeNode(unsigned int hostid)
 
     HostItem *hostItem = findHostItem(hostid);
 
-    if (hostItem && hostItem->hostInfo()->isOffline()) {
-        removeItem(hostItem);
-    }
-}
+    if (!hostItem)
+	    return;
 
-void StarView::forceRemoveNode(unsigned int hostid)
-{
-    HostItem *hostItem = findHostItem(hostid);
-
-    if (hostItem) {
-        removeItem(hostItem);
-    }
-}
-
-void StarView::removeItem(HostItem *hostItem)
-{
-    m_hostItems.remove(hostItem->hostInfo()->id());
+    m_hostItems.remove(hostid);
 
     QList<unsigned int> obsoleteJobs;
 
@@ -621,7 +609,7 @@ void StarView::slotConfigChanged()
         if (filterArch(*it)) {
             checkNode(it.key());
         } else {
-            forceRemoveNode(it.key());
+            removeNode(it.key());
         }
     }
 
